==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ACmpgeBinop.h <==
// public final class soot.jimple.parser.node.ACmpgeBinop

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e9ed63b321dfd981 soot_jimple_parser_node_ACmpgeBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpgeBinop_H_
#define _JC_soot_jimple_parser_node_ACmpgeBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpge$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$refs	_jc_soot_jimple_parser_node_ACmpgeBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$object	_jc_soot_jimple_parser_node_ACmpgeBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpgeBinop$vmethods	_jc_soot_jimple_parser_node_ACmpgeBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtable	_jc_soot_jimple_parser_node_ACmpgeBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtype	_jc_soot_jimple_parser_node_ACmpgeBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$_init$ac1c2fa4423c3b5f(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_TCmpge$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpgeBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *);
extern struct _jc_soot_jimple_parser_node_TCmpge$object *_jc_soot_jimple_parser_node_ACmpgeBinop$method$getCmpge$be50b4e85302d064(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *);
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$setCmpge$d01c10e11d83b825(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_TCmpge$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpgeBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$getCmpge$be50b4e85302d064;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$setCmpge$d01c10e11d83b825;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpgeBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *);
	struct _jc_soot_jimple_parser_node_TCmpge$object	*(*getCmpge$be50b4e85302d064)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setCmpge$d01c10e11d83b825)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_TCmpge$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpgeBinop$vmethods	soot_jimple_parser_node_ACmpgeBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpgeBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpge$object	*__5fcmpge__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$refs {
    _jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs	soot_jimple_parser_node_ACmpgeBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs	soot_jimple_parser_node_ACmpgeBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpgeBinop$object {
	_jc_soot_jimple_parser_node_ACmpgeBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpgeBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpgeBinop$vtype _jc_soot_jimple_parser_node_ACmpgeBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpgeBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpgeBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpgeBinop_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ACmpgeBinop.h <==
// public final class soot.jimple.parser.node.ACmpgeBinop

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e9ed63b321dfd981 soot_jimple_parser_node_ACmpgeBinop
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b86441297795c006 soot_jimple_parser_node_PBinop

// header file dependencies
// @dep_header soot_jimple_parser_node_PBinop

#include "soot/jimple/parser/node/PBinop.h"

#ifndef _JC_soot_jimple_parser_node_ACmpgeBinop_H_
#define _JC_soot_jimple_parser_node_ACmpgeBinop_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TCmpge$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs	_jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs	_jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$refs	_jc_soot_jimple_parser_node_ACmpgeBinop$refs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs	_jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ACmpgeBinop$object	_jc_soot_jimple_parser_node_ACmpgeBinop$object;

typedef const struct _jc_soot_jimple_parser_node_ACmpgeBinop$vmethods	_jc_soot_jimple_parser_node_ACmpgeBinop$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtable	_jc_soot_jimple_parser_node_ACmpgeBinop$vtable;
typedef const struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtype	_jc_soot_jimple_parser_node_ACmpgeBinop$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$_init$ac1c2fa4423c3b5f(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_TCmpge$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ACmpgeBinop$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TCmpge$object *_jc_soot_jimple_parser_node_ACmpgeBinop$method$getCmpge$be50b4e85302d064(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ACmpgeBinop$method$setCmpge$d01c10e11d83b825(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_TCmpge$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ACmpgeBinop$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$getCmpge$be50b4e85302d064;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$setCmpge$d01c10e11d83b825;
extern _jc_method _jc_soot_jimple_parser_node_ACmpgeBinop$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ACmpgeBinop$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TCmpge$object	*(*getCmpge$be50b4e85302d064)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setCmpge$d01c10e11d83b825)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *, struct _jc_soot_jimple_parser_node_TCmpge$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ACmpgeBinop$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBinop$vmethods	soot_jimple_parser_node_PBinop;
	_jc_soot_jimple_parser_node_ACmpgeBinop$vmethods	soot_jimple_parser_node_ACmpgeBinop;
};

// Vtype
struct _jc_soot_jimple_parser_node_ACmpgeBinop$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ACmpgeBinop$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs {
	struct _jc_soot_jimple_parser_node_TCmpge$object	*__5fcmpge__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$refs {
    _jc_soot_jimple_parser_node_ACmpgeBinop$sub_refs	soot_jimple_parser_node_ACmpgeBinop;
    _jc_soot_jimple_parser_node_PBinop$sub_refs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBinop$sub_nonrefs	soot_jimple_parser_node_PBinop;
    _jc_soot_jimple_parser_node_ACmpgeBinop$sub_nonrefs	soot_jimple_parser_node_ACmpgeBinop;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ACmpgeBinop$object {
	_jc_soot_jimple_parser_node_ACmpgeBinop$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ACmpgeBinop$vtype	*vtype;
	_jc_soot_jimple_parser_node_ACmpgeBinop$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ACmpgeBinop$vtype _jc_soot_jimple_parser_node_ACmpgeBinop$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ACmpgeBinop, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ACmpgeBinop$class_object;

#endif	/* _JC_soot_jimple_parser_node_ACmpgeBinop_H_ */
